# 2025 - Universidad de El Salvador - Ingenieria en Desarrollo de Software
# Cálculo Numérico para el Desarrollo de Aplicaciones
# Examen Corto 1 - Grupo Teórico 2

**IC23005** es una librería que permite resolver sistemas ecuaciones lineales y no lineales con diferentes metodos.

## Métodos Incluidos

• **Sistemas de ecuaciones lineales :**
    ○ Eliminación de Gauss (`eliminacion_gauss_`)
    ○ Eliminación de Gauss-Jordan (`eliminacion_gauss_jorda`)
    ○ Regla de Cramer (`regla_cramer`)
    ○ Descomposición LU (`descomposicion_lu`)
    ○ Método de Jacobi (`metodo_jacobi`)
    ○ Método de Gauss-Seidel (`metodo_gauss_seidel`)
• **Sistemas de ecuaciones no lineales:**
    ○ Método de Bisección (`metodo_bisection`)

## Licencia

MIT License © Erick Israel Iraheta Contreras

## Instalación

Puedes instalar la librería __pip install__ desde **PyPI**:

```bash
pip install IC23005UNO